package de.firstdata.ipg.api.client;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.StringReader;
import java.io.StringWriter;

import javax.xml.transform.OutputKeys;
import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.TransformerFactoryConfigurationError;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;

public class XMLTransformer {

	private static TransformerFactory transformerFactory;

	private static byte[] bytes;

	private XMLTransformer() {
		// util class
	}

	/**
	 * Returns a new initialized xml formatter.
	 * 
	 * @return new xml formatter
	 * @throws TransformerConfigurationException
	 *             configuration error
	 */
	public static Transformer getXMLTransformer() throws TransformerConfigurationException {
		if (transformerFactory == null) {
			createTransformerFactory();
			if (transformerFactory == null) {
				return null;
			}
		}
		final Transformer transformer = transformerFactory.newTransformer(new StreamSource(new ByteArrayInputStream(bytes)));
		transformer.setOutputProperty(OutputKeys.INDENT, "yes");
		return transformer;
	}

	private synchronized static void createTransformerFactory() throws TransformerConfigurationException {
		if (transformerFactory != null) {
			return;
		}
		try (final InputStream inputStream = XMLTransformer.class.getResourceAsStream("/config/indent.xsl")) {
			bytes = new byte[inputStream.available()];
			inputStream.read(bytes);
		} catch (final IOException e) {
			throw new TransformerConfigurationException("", e);
		}
		transformerFactory = TransformerFactory.newInstance();
	}

	public static String transform(final Source xml) throws TransformerConfigurationException, TransformerException, TransformerFactoryConfigurationError {
		final StringWriter stringWriter = new StringWriter();
		final Transformer transformer = getXMLTransformer();
		if (transformer == null) {
			return null;
		}
		transformer.transform(xml, new StreamResult(stringWriter));
		return stringWriter.toString();
	}

	public static String transform(final String xml) {
		try {
			final String formatted = transform(new StreamSource(new StringReader(xml)));
			return formatted == null ? xml : formatted;
		} catch (final TransformerConfigurationException e) {
			return xml;
		} catch (final TransformerException e) {
			return xml;
		} catch (final TransformerFactoryConfigurationError e) {
			return xml;
		}
	}
}
