package de.firstdata.ipg.api.client.action;

import java.util.Date;

import de.firstdata.ipg.api.client.action.catalog.DeleteProductStock;
import de.firstdata.ipg.api.client.action.catalog.DeleteProducts;
import de.firstdata.ipg.api.client.action.catalog.DisplayProductStock;
import de.firstdata.ipg.api.client.action.catalog.DisplayProducts;
import de.firstdata.ipg.api.client.action.catalog.StoreProductStock;
import de.firstdata.ipg.api.client.action.catalog.StoreProducts;
import de.firstdata.ipg.api.client.action.catalog.object.DeleteProductStockObject;
import de.firstdata.ipg.api.client.action.catalog.object.DeleteProductsObject;
import de.firstdata.ipg.api.client.action.catalog.object.DisplayProductStockObject;
import de.firstdata.ipg.api.client.action.catalog.object.DisplayProductsObject;
import de.firstdata.ipg.api.client.action.catalog.object.StoreProductStockObject;
import de.firstdata.ipg.api.client.action.catalog.object.StoreProductsObject;
import de.firstdata.ipg.api.client.action.datastorage.DeleteHostedData;
import de.firstdata.ipg.api.client.action.datastorage.DisplayHostedData;
import de.firstdata.ipg.api.client.action.datastorage.StoreHostedData;
import de.firstdata.ipg.api.client.action.datastorage.object.DeleteHostedDataObject;
import de.firstdata.ipg.api.client.action.datastorage.object.DisplayHostedDataObject;
import de.firstdata.ipg.api.client.action.datastorage.object.StoreHostedDataObject;
import de.firstdata.ipg.api.client.action.object.GetExternalConsumerInformationObject;
import de.firstdata.ipg.api.client.action.object.GetExternalTransactionStatusObject;
import de.firstdata.ipg.api.client.action.object.GetLastTransactionsObject;
import de.firstdata.ipg.api.client.action.object.InitiatedClearingObject;
import de.firstdata.ipg.api.client.action.object.InquiryCardInformationObject;
import de.firstdata.ipg.api.client.action.object.InquiryOrderObject;
import de.firstdata.ipg.api.client.action.object.InquiryTransactionObject;
import de.firstdata.ipg.api.client.action.object.RequestCardRateForDCCObject;
import de.firstdata.ipg.api.client.action.object.RequestMerchantRateForDynamicPricingObject;
import de.firstdata.ipg.api.client.action.object.SendEMailNotificationObject;
import de.firstdata.ipg.api.client.action.object.ValidateObject;
import de.firstdata.ipg.api.client.action.recurringpayment.CancelRecurringPayment;
import de.firstdata.ipg.api.client.action.recurringpayment.InstallRecurringPayment;
import de.firstdata.ipg.api.client.action.recurringpayment.ModifyRecurringPayment;
import de.firstdata.ipg.api.client.action.recurringpayment.PerformOnlyInTestEnvironmentRecurringPayment;
import de.firstdata.ipg.api.client.action.recurringpayment.object.CancelRecurringPaymentObject;
import de.firstdata.ipg.api.client.action.recurringpayment.object.InstallRecurringPaymentObject;
import de.firstdata.ipg.api.client.action.recurringpayment.object.ModifyRecurringPaymentObject;
import de.firstdata.ipg.api.client.action.recurringpayment.object.PerformOnlyInTestEnvironmentRecurringPaymentObject;
import de.firstdata.ipg.api.client.transaction.Amount;
import de.firstdata.ipg.api.client.transaction.creditcard.CreditCard;
import de.firstdata.ipg.api.client.transaction.customercard.CustomerCard;
import de.firstdata.ipg.api.client.transaction.dedirectdebit.DEDirectDebit;

public class IPGApiActionFactory {

	public static InitiatedClearing createInitiatedClearing() {
		return new InitiatedClearingObject();
	}

	public static InquiryOrder createInquiryOrder(final String orderID) {
		return new InquiryOrderObject(orderID);
	}

	public static InquiryTransaction createInquiryTransaction(final String orderID, final String tDate) {
		return new InquiryTransactionObject(orderID, tDate);
	}

	public static InquiryCardInformation createInquiryCardInformation(final String cardNumber) {
		return new InquiryCardInformationObject(cardNumber);
	}

	public static DeleteHostedData createDeleteHostedData(final String hostedDataID) {
		return new DeleteHostedDataObject(hostedDataID);
	}

	public static DisplayHostedData createDisplayHostedData(final String hostedDataID) {
		return new DisplayHostedDataObject(hostedDataID);
	}

	public static StoreHostedData createStoreHostedData() {
		return new StoreHostedDataObject();
	}

	public static InstallRecurringPayment createInstallRecurringPayment(final Amount amount, final CreditCard creditCard, final int installmentFrequency,
			final String installmentPeriod, final int maximumFailures, final Date recurringStartDate) {
		return new InstallRecurringPaymentObject(amount, creditCard, installmentFrequency, installmentPeriod, maximumFailures, recurringStartDate);
	}

	public static InstallRecurringPayment createInstallRecurringPayment(final Amount amount, final CreditCard creditCard, final int installmentFrequency,
			final String installmentPeriod, final int maximumFailures, final String recurringStartDate) {
		return new InstallRecurringPaymentObject(amount, creditCard, installmentFrequency, installmentPeriod, maximumFailures, recurringStartDate);
	}

	public static InstallRecurringPayment createInstallRecurringPayment(final Amount amount, final DEDirectDebit deDirectDebit, final int installmentFrequency,
			final String installmentPeriod, final int maximumFailures, final Date recurringStartDate) {
		return new InstallRecurringPaymentObject(amount, deDirectDebit, installmentFrequency, installmentPeriod, maximumFailures, recurringStartDate);
	}

	public static InstallRecurringPayment createInstallRecurringPayment(final Amount amount, final DEDirectDebit deDirectDebit, final int installmentFrequency,
			final String installmentPeriod, final int maximumFailures, final String recurringStartDate) {
		return new InstallRecurringPaymentObject(amount, deDirectDebit, installmentFrequency, installmentPeriod, maximumFailures, recurringStartDate);
	}

	public static InstallRecurringPayment createInstallRecurringPayment(final Amount amount, final String referencedOrderID, final int installmentFrequency,
			final String installmentPeriod, final int maximumFailures, final Date recurringStartDate) {
		return new InstallRecurringPaymentObject(amount, referencedOrderID, installmentFrequency, installmentPeriod, maximumFailures, recurringStartDate);
	}

	public static InstallRecurringPayment createInstallRecurringPayment(final Amount amount, final String referencedOrderID, final int installmentFrequency,
			final String installmentPeriod, final int maximumFailures, final String recurringStartDate) {
		return new InstallRecurringPaymentObject(amount, referencedOrderID, installmentFrequency, installmentPeriod, maximumFailures, recurringStartDate);
	}

	public static InstallRecurringPayment createInstallRecurringPayment(final Amount amount, final String hostedDataID, final String hostedDataStoreID,
			final int installmentFrequency, final String installmentPeriod, final int maximumFailures, final Date recurringStartDate) {
		return new InstallRecurringPaymentObject(amount, hostedDataID, hostedDataStoreID, installmentFrequency, installmentPeriod, maximumFailures,
				recurringStartDate);
	}

	public static InstallRecurringPayment createInstallRecurringPayment(final Amount amount, final String hostedDataID, final String hostedDataStoreID,
			final int installmentFrequency, final String installmentPeriod, final int maximumFailures, final String recurringStartDate) {
		return new InstallRecurringPaymentObject(amount, hostedDataID, hostedDataStoreID, installmentFrequency, installmentPeriod, maximumFailures,
				recurringStartDate);
	}

	public static ModifyRecurringPayment createModifyRecurringPayment(final String orderId) {
		return new ModifyRecurringPaymentObject(orderId);
	}

	public static CancelRecurringPayment createCancelRecurringPayment(final String orderId) {
		return new CancelRecurringPaymentObject(orderId);
	}

	public static PerformOnlyInTestEnvironmentRecurringPayment createPerformOnlyInTestEnvironmentRecurringPayment(final String orderId) {
		return new PerformOnlyInTestEnvironmentRecurringPaymentObject(orderId);
	}

	public static Validate createValidate(final CreditCard card) {
		return new ValidateObject(card);
	}

	public static Validate createValidate(final CustomerCard card) {
		return new ValidateObject(card);
	}

	public static Validate createValidate(final DEDirectDebit account) {
		return new ValidateObject(account);
	}

	public static Validate createValidate(final String hostedDataID) {
		return new ValidateObject(hostedDataID);
	}

	public static SendEMailNotification createSendEMailNotification(final String orderID, final String tDate) {
		return new SendEMailNotificationObject(orderID, tDate);
	}

	public static GetExternalTransactionStatus createGetExternalTransactionStatus(final String orderID, final String tDate) {
		return new GetExternalTransactionStatusObject(orderID, tDate);
	}

	public static GetExternalTransactionStatus createGetExternalTransactionStatus(final String merchantTransactionId) {
		return new GetExternalTransactionStatusObject(merchantTransactionId);
	}

	public static GetExternalTransactionStatus createGetExternalTransactionStatus(final Long ipgTransactionId) {
		return new GetExternalTransactionStatusObject(ipgTransactionId);
	}

	public static GetLastTransactions createGetLastTransactions() {
		return new GetLastTransactionsObject();
	}

	public static GetExternalConsumerInformation createGetExternalConsumerInformation(final String firstName, final String surname, final Date birthday,
			final String street, final String houseNumber, final String postCode, final String city, final String country, final String dataProvider) {
		return new GetExternalConsumerInformationObject(firstName, surname, birthday, street, houseNumber, postCode, city, country, dataProvider);
	}

	public static GetExternalConsumerInformation createGetExternalConsumerInformation(final String firstName, final String surname, final String birthday,
			final String street, final String houseNumber, final String postCode, final String city, final String country, final String dataProvider) {
		return new GetExternalConsumerInformationObject(firstName, surname, birthday, street, houseNumber, postCode, city, country, dataProvider);
	}

	public static StoreProducts createStoreProducts() {
		return new StoreProductsObject();
	}

	public static DisplayProducts createDisplayProducts() {
		return new DisplayProductsObject();
	}

	public static DeleteProducts createDeleteProducts() {
		return new DeleteProductsObject();
	}

	public static StoreProductStock createStoreProductStock() {
		return new StoreProductStockObject();
	}

	public static DisplayProductStock createDisplayProductStock() {
		return new DisplayProductStockObject();
	}

	public static DeleteProductStock createDeleteProductStock() {
		return new DeleteProductStockObject();
	}

	public static RequestCardRateForDCC createCardRateForDCC() {
		return new RequestCardRateForDCCObject();
	}

	public static RequestMerchantRateForDynamicPricing createMerchantRateForDynamicPricing() {
		return new RequestMerchantRateForDynamicPricingObject();
	}
}
