package de.firstdata.ipg.api.client.transaction;

import de.firstdata.ipg.api.client.transaction.alipay.AlipayReturnTransaction;
import de.firstdata.ipg.api.client.transaction.alipay.AlipaySaleTransaction;
import de.firstdata.ipg.api.client.transaction.alipay.object.AlipayReturnTransactionObject;
import de.firstdata.ipg.api.client.transaction.alipay.object.AlipaySaleTransactionObject;
import de.firstdata.ipg.api.client.transaction.alipay.object.AlipaylVoidTransactionObject;
import de.firstdata.ipg.api.client.transaction.apm.sepapayout.SepaCreditTransaction;
import de.firstdata.ipg.api.client.transaction.apm.sepapayout.object.SepaCreditTransactionObject;
import de.firstdata.ipg.api.client.transaction.creditcard.CCCreditTransaction;
import de.firstdata.ipg.api.client.transaction.creditcard.CCForceTicketTransaction;
import de.firstdata.ipg.api.client.transaction.creditcard.CCPayerAuthTransaction;
import de.firstdata.ipg.api.client.transaction.creditcard.CCPostAuthTransaction;
import de.firstdata.ipg.api.client.transaction.creditcard.CCPreAuthTransaction;
import de.firstdata.ipg.api.client.transaction.creditcard.CCReturnTransaction;
import de.firstdata.ipg.api.client.transaction.creditcard.CCSaleTransaction;
import de.firstdata.ipg.api.client.transaction.creditcard.CCVoidTransaction;
import de.firstdata.ipg.api.client.transaction.creditcard.CreditCard;
import de.firstdata.ipg.api.client.transaction.creditcard.object.CCCreditTransactionObject;
import de.firstdata.ipg.api.client.transaction.creditcard.object.CCForceTicketTransactionObject;
import de.firstdata.ipg.api.client.transaction.creditcard.object.CCPayerAuthTransactionObject;
import de.firstdata.ipg.api.client.transaction.creditcard.object.CCPostAuthTransactionObject;
import de.firstdata.ipg.api.client.transaction.creditcard.object.CCPreAuthTransactionObject;
import de.firstdata.ipg.api.client.transaction.creditcard.object.CCReturnTransactionObject;
import de.firstdata.ipg.api.client.transaction.creditcard.object.CCSaleTransactionObject;
import de.firstdata.ipg.api.client.transaction.creditcard.object.CCVoidTransactionObject;
import de.firstdata.ipg.api.client.transaction.customercard.CustomerCForceTicketTransaction;
import de.firstdata.ipg.api.client.transaction.customercard.CustomerCSaleTransaction;
import de.firstdata.ipg.api.client.transaction.customercard.CustomerCard;
import de.firstdata.ipg.api.client.transaction.customercard.object.CustomerCForceTicketTransactionObject;
import de.firstdata.ipg.api.client.transaction.customercard.object.CustomerCSaleTransactionObject;
import de.firstdata.ipg.api.client.transaction.dedirectdebit.DEDDCreditTransaction;
import de.firstdata.ipg.api.client.transaction.dedirectdebit.DEDDReturnTransaction;
import de.firstdata.ipg.api.client.transaction.dedirectdebit.DEDDSaleTransaction;
import de.firstdata.ipg.api.client.transaction.dedirectdebit.DEDDVoidTransaction;
import de.firstdata.ipg.api.client.transaction.dedirectdebit.DEDirectDebit;
import de.firstdata.ipg.api.client.transaction.dedirectdebit.object.DEDDCreditTransactionObject;
import de.firstdata.ipg.api.client.transaction.dedirectdebit.object.DEDDReturnTransactionObject;
import de.firstdata.ipg.api.client.transaction.dedirectdebit.object.DEDDSaleTransactionObject;
import de.firstdata.ipg.api.client.transaction.dedirectdebit.object.DEDDVoidTransactionObject;
import de.firstdata.ipg.api.client.transaction.ideal.IdealReturnTransaction;
import de.firstdata.ipg.api.client.transaction.ideal.object.IdealReturnTransactionObject;
import de.firstdata.ipg.api.client.transaction.klarna.KlarnaPostAuthTransaction;
import de.firstdata.ipg.api.client.transaction.klarna.KlarnaPreAuthTransaction;
import de.firstdata.ipg.api.client.transaction.klarna.KlarnaReturnTransaction;
import de.firstdata.ipg.api.client.transaction.klarna.KlarnaVoidTransaction;
import de.firstdata.ipg.api.client.transaction.klarna.object.KlarnaPostAuthTransactionObject;
import de.firstdata.ipg.api.client.transaction.klarna.object.KlarnaPreAuthTransactionObject;
import de.firstdata.ipg.api.client.transaction.klarna.object.KlarnaReturnTransactionObject;
import de.firstdata.ipg.api.client.transaction.klarna.object.KlarnaVoidTransactionObject;
import de.firstdata.ipg.api.client.transaction.paypal.PayPalCreditTransaction;
import de.firstdata.ipg.api.client.transaction.paypal.PayPalPostAuthTransaction;
import de.firstdata.ipg.api.client.transaction.paypal.PayPalReturnTransaction;
import de.firstdata.ipg.api.client.transaction.paypal.PayPalVoidTransaction;
import de.firstdata.ipg.api.client.transaction.paypal.object.PayPalCreditTransactionObject;
import de.firstdata.ipg.api.client.transaction.paypal.object.PayPalPostAuthTransactionObject;
import de.firstdata.ipg.api.client.transaction.paypal.object.PayPalReturnTransactionObject;
import de.firstdata.ipg.api.client.transaction.paypal.object.PayPalVoidTransactionObject;
import de.firstdata.ipg.api.client.transaction.sofort.SofortReturnTransaction;
import de.firstdata.ipg.api.client.transaction.sofort.object.SofortReturnTransactionObject;
import de.firstdata.ipg.api.client.transaction.softwareexpress.object.BoletoSaleTransactionObject;
import de.firstdata.ipg.api.client.transaction.topup.MobilePhoneChargeTransaction;
import de.firstdata.ipg.api.client.transaction.topup.object.MobilePhoneChargeTransactionObject;

/**
 * generates all possible transactions
 *
 * @author i176hft
 *
 */
public class IPGApiTransactionFactory {

	// ///////////////////////
	// CreditCard-Transactions

	/**
	 * method should be used for Authentication of Payer Auth transaction
	 *
	 * @return new {@link CCPayerAuthTransactionObject}
	 */
	public static CCPayerAuthTransaction createPayerAuthTransaction() {
		return new CCPayerAuthTransactionObject();
	}

	/**
	 * @return new {@link CCPayerAuthTransactionObject}
	 */
	public static CCPayerAuthTransaction createPayerAuthTransaction(final Amount amount, final CreditCard creditCard) {
		return new CCPayerAuthTransactionObject(amount, creditCard);
	}

	/**
	 * Method is used for Authentication of IVR Secure 3D transaction
	 *
	 * @return new CCSaleTransactionObject();
	 */
	public static CCSaleTransaction createSaleTransactionCredit() {
		return new CCSaleTransactionObject();
	}

	/**
	 * @return new CCSaleTransactionObject(amount, creditCard);
	 */
	public static CCSaleTransaction createSaleTransactionCredit(final Amount amount, final CreditCard creditCard) {
		return new CCSaleTransactionObject(amount, creditCard);
	}

	/**
	 * @return new CCSaleTransactionObject(amount, hostedDataID);
	 */
	public static CCSaleTransaction createSaleTransactionCredit(final Amount amount, final String hostedDataID) {
		return new CCSaleTransactionObject(amount, hostedDataID, null);
	}

	/**
	 * @return new CCSaleTransactionObject(amount, hostedDataID);
	 */
	public static CCSaleTransaction createSaleTransactionCredit(final Amount amount, final String hostedDataID, final String hostedDataStoreID) {
		return new CCSaleTransactionObject(amount, hostedDataID, hostedDataStoreID);
	}

	/**
	 * Method is used for Authentication of IVR Secure 3D transaction
	 *
	 * @return new CCPreAuthTransactionObject();
	 */
	public static CCPreAuthTransaction createPreAuthTransactionCredit() {
		return new CCPreAuthTransactionObject();
	}

	/**
	 * @return new CCPreAuthTransactionObject(amount, creditCard);
	 */
	public static CCPreAuthTransaction createPreAuthTransactionCredit(final Amount amount, final CreditCard creditCard) {
		return new CCPreAuthTransactionObject(amount, creditCard);
	}

	/**
	 * @return new CCPreAuthTransactionObject(amount, hostedDataID);
	 */
	public static CCPreAuthTransaction createPreAuthTransactionCredit(final Amount amount, final String hostedDataID) {
		return new CCPreAuthTransactionObject(amount, hostedDataID, null);
	}

	/**
	 * @return new CCPreAuthTransactionObject(amount, hostedDataID);
	 */
	public static CCPreAuthTransaction createPreAuthTransactionCredit(final Amount amount, final String hostedDataID, final String hostedDataStoreID) {
		return new CCPreAuthTransactionObject(amount, hostedDataID, hostedDataStoreID);
	}

	/**
	 * @return new CCPostAuthTransactionObject(amount, orderId);
	 */
	public static CCPostAuthTransaction createPostAuthTransactionCredit(final Amount amount, final String orderId) {
		return new CCPostAuthTransactionObject(amount, orderId);
	}

	/**
	 * @return new CCForceTicketTransactionObject(amount, creditCard,
	 *         referenceNumber);
	 */
	public static CCForceTicketTransaction createForceTicketTransactionCredit(final Amount amount, final CreditCard creditCard, final String referenceNumber) {
		return new CCForceTicketTransactionObject(amount, creditCard, referenceNumber);
	}

	/**
	 * @return CCForceTicketTransactionObject(amount, hostedDataID,
	 *         referenceNumber);
	 */
	public static CCForceTicketTransaction createForceTicketTransactionCredit(final Amount amount, final String hostedDataID, final String referenceNumber) {
		return new CCForceTicketTransactionObject(amount, hostedDataID, null, referenceNumber);
	}

	/**
	 * @return CCForceTicketTransactionObject(amount, hostedDataID,
	 *         referenceNumber);
	 */
	public static CCForceTicketTransaction createForceTicketTransactionCredit(final Amount amount, final String hostedDataID, final String hostedDataStoreID,
			final String referenceNumber) {
		return new CCForceTicketTransactionObject(amount, hostedDataID, hostedDataStoreID, referenceNumber);
	}

	/**
	 * @return new CCReturnTransactionObject(amount, orderId);
	 */
	public static CCReturnTransaction createReturnTransactionCredit(final Amount amount, final String orderId) {
		return new CCReturnTransactionObject(amount, orderId);
	}

	/**
	 * @return new CCCreditTransactionObject(amount, creditCard);
	 */
	public static CCCreditTransaction createCreditTransactionCredit(final Amount amount, final CreditCard creditCard) {
		return new CCCreditTransactionObject(amount, creditCard);
	}

	/**
	 * @return new CCCreditTransactionObject(amount, hostedDataID);
	 */
	public static CCCreditTransaction createCreditTransactionCredit(final Amount amount, final String hostedDataID) {
		return new CCCreditTransactionObject(amount, hostedDataID, null);
	}

	/**
	 * @return new CCCreditTransactionObject(amount, hostedDataID);
	 */
	public static CCCreditTransaction createCreditTransactionCredit(final Amount amount, final String hostedDataID, final String hostedDataStoreID) {
		return new CCCreditTransactionObject(amount, hostedDataID, hostedDataStoreID);
	}

	/**
	 * @return new CCVoidTransactionObject(orderId, tDate);
	 */
	public static CCVoidTransaction createVoidTransactionCredit(final String orderId, final String tDate) {
		return new CCVoidTransactionObject(orderId, tDate);
	}

	// ///////////////////////////////
	// Customer card-Transactions

	/**
	 * @return new CustomerCSaleTransactionObject(amount, customerCard);
	 */
	public static CustomerCSaleTransaction createCustomerCSaleTransaction(final Amount amount, final CustomerCard customerCard) {
		return new CustomerCSaleTransactionObject(amount, customerCard);
	}

	/**
	 * @return new CustomerCForceTicketTransactionObject(amount, customerCard,
	 *         referenceNumber);
	 */
	public static CustomerCForceTicketTransaction createCustomerCForceTicketTransaction(final Amount amount, final CustomerCard customerCard,
			final String referenceNumber) {
		return new CustomerCForceTicketTransactionObject(amount, customerCard, referenceNumber);
	}

	// ///////////////////////////////
	// German DirectDebit-Transactions

	/**
	 * @return new DEDDSaleTransactionObject(amount, directDebit);
	 */
	public static DEDDCreditTransaction createCreditTransactionDebitDE(final Amount amount, final DEDirectDebit directDebit) {
		return new DEDDCreditTransactionObject(amount, directDebit);
	}

	/**
	 * @return new DEDDSaleTransactionObject(amount, directDebit);
	 */
	public static DEDDReturnTransaction createReturnTransactionDebitDE(final Amount amount, final String orderId) {
		return new DEDDReturnTransactionObject(amount, orderId);
	}

	/**
	 * @return new DEDDSaleTransactionObject(amount, directDebit);
	 */
	public static DEDDSaleTransaction createSaleTransactionDebitDE(final Amount amount, final DEDirectDebit directDebit) {
		return new DEDDSaleTransactionObject(amount, directDebit);
	}

	/**
	 * @return new DEDDSaleTransactionObject(amount, directDebit, hostedDataID);
	 */
	public static DEDDSaleTransaction createSaleTransactionDebitDE(final Amount amount, final String hostedDataID) {
		return new DEDDSaleTransactionObject(amount, hostedDataID, null);
	}

	/**
	 * @return new DEDDSaleTransactionObject(amount, directDebit, hostedDataID);
	 */
	public static DEDDSaleTransaction createSaleTransactionDebitDE(final Amount amount, final String hostedDataID, final String hostedDataStoreID) {
		return new DEDDSaleTransactionObject(amount, hostedDataID, hostedDataStoreID);
	}

	/**
	 * @return new DEDDVoidTransactionObject(orderId, tDate);
	 */
	public static DEDDVoidTransaction createVoidTransactionDebitDE(final String orderId, final String tDate) {
		return new DEDDVoidTransactionObject(orderId, tDate);
	}

	// ///////////////////////////////
	// Ideal Transactions

	public static IdealReturnTransaction createReturnTransactionIdeal(final Amount amount, final String orderId) {
		return new IdealReturnTransactionObject(amount, orderId);
	}

	// ///////////////////////////////
	// PayPal-Transactions

	public static PayPalCreditTransaction createCreditTransactionPayPal(final Amount amount) {
		return new PayPalCreditTransactionObject(amount);
	}

	public static PayPalPostAuthTransaction createPostAuthTransactionPayPal(final Amount amount, final String orderId) {
		return new PayPalPostAuthTransactionObject(amount, orderId);
	}

	public static PayPalReturnTransaction createReturnTransactionPayPal(final Amount amount, final String orderId) {
		return new PayPalReturnTransactionObject(amount, orderId);
	}

	public static PayPalVoidTransaction createVoidTransactionPayPal(final String orderId, final String tDate) {
		return new PayPalVoidTransactionObject(orderId, tDate);
	}

	// ///////////////////////////////
	// Sofort-Transactions

	public static SofortReturnTransaction createReturnTransactionSofort(final Amount amount, final String orderId) {
		return new SofortReturnTransactionObject(amount, orderId);
	}

	// ///////////////////////////////
	// TopUp-Transactions

	public static MobilePhoneChargeTransaction createMobilePhoneChargeTransaction(final Amount amount, final String mobileNetworkServiceProvider,
			final String mobilePhoneNumber, final String type) {
		return new MobilePhoneChargeTransactionObject(amount, mobileNetworkServiceProvider, mobilePhoneNumber, type);
	}

	// //////////////////////////////
	// Klarna-Transactions

	public static KlarnaPreAuthTransaction createKlarnaPreAuthTransaction(final Amount amount) {
		return new KlarnaPreAuthTransactionObject(amount);
	}

	public static KlarnaPostAuthTransaction createKlarnaPostAuthTransaction(final Amount amount, final String orderId, final String tDate) {
		return new KlarnaPostAuthTransactionObject(amount, orderId, tDate);
	}

	public static KlarnaVoidTransaction createKlarnaVoidTransaction(final String orderId, final String tDate) {
		return new KlarnaVoidTransactionObject(orderId, tDate);
	}

	public static KlarnaReturnTransaction createKlarnaReturnTransaction(final Amount amount, final String orderId, final String tDate) {
		return new KlarnaReturnTransactionObject(amount, orderId, tDate);
	}

	// //////////////////////////////
	// PPRO

	public static SepaCreditTransaction createSepaCreditTransaction(final Amount amount, final String orderId) {
		return new SepaCreditTransactionObject(amount, orderId);
	}

	public static SepaSaleTransaction createSepaSaleTransaction(final Amount amount, final String orderId) {
		return new SepaSaleTransactionObject(amount, orderId);
	}

	public static AlipaySaleTransaction createSaleTransactionAlipayPaySecure(final Amount amount, final String orderId) {
		return new AlipaySaleTransactionObject(amount, orderId);
	}

	public static AlipayReturnTransaction createReturnTransactionAlipayPaySecure(final Amount amount, final String orderId) {
		return new AlipayReturnTransactionObject(amount, orderId);
	}

	public static AlipaylVoidTransactionObject createVoidTransactionAlipayPaySecure(final String orderID, final String tDate) {
		return new AlipaylVoidTransactionObject(orderID, tDate);
	}

	// //////////////////////////////
	// Boleto-Transactions
	public static BoletoSaleTransactionObject createBoletoSaleTransaction(final Amount amount, final String orderId, final String authorizerId) {
		return new BoletoSaleTransactionObject(amount, orderId, authorizerId);
	}
}
