package de.firstdata.ipg.api.client.transaction.creditcard.object;

import de.firstdata.ipg.api.client.IPGApiClient;
import de.firstdata.ipg.api.client.IPGApiResult;
import de.firstdata.ipg.api.client.transaction.creditcard.CCVoidTransaction;

/**
 * This class represents a <i>Void</i> transaction and allows for setting its
 * optional attributes by calling the appropriate <code>setter</code> methods.
 * An instance of this class is created when calling
 * {@link IPGApiClient#createVoidTransaction(String, String)}.
 * 
 * @author Andreas Schmid
 */
public final class CCVoidTransactionObject extends CCTransactionObject implements CCVoidTransaction {

	/**
	 * creates a <i>Void</i> transaction with the minimum set of parameters -
	 * note that you can add optional fields by calling the appropriate
	 * <code>setter</code> methods on the returned {@link CCVoidTransactionObject}
	 * instance
	 * 
	 * @param orderId
	 *            the order ID this transaction refers to and which is contained
	 *            in an {@link IPGApiResult} instance returned as result to a
	 *            successful transaction of any other type - call
	 *            {@link IPGApiResult#getOrderId()} for accessing this order ID
	 * @param tDate
	 *            the tDate which identifies the transaction to be voided
	 * @return the {@link CCVoidTransactionObject} instance with the transaction
	 *         parameters set to the operation arguments
	 */
	public CCVoidTransactionObject(final String orderId, final String tDate) {
		super("void", null, null, null, null, orderId);
		getTransactionDetails().setTDate(tDate);
	}
}
